import os
import argparse

from sonotoria import jaml

from .project import create_full_project


def main():
    parser = argparse.ArgumentParser(description='Initiate a project on Gitlab.')
    parser.add_argument('conf_path', type=str, help='The config file')
    parser.add_argument('--token', dest='token', type=str, help='The gitlab token')

    args = parser.parse_args()

    conf = jaml.load(args.conf_path)
    conf['token'] = args.token or os.environ['GL_TOKEN']
    create_full_project(conf)


if __name__ == '__main__':
    main()



import os
from setuptools import setup


if __name__ == '__main__':
    setup(
        version=os.environ.get('CI_COMMIT_TAG', '0.0.0'),
        long_description=open('README.md').read() + '\n\n\n' + open('CHANGELOG.md').read(),
        long_description_content_type='text/markdown'
    )



LABELS = {
    'TBR': '#AD8D43',
    'Backlog': '#5843AD',
    'Critical': '#FF0000',
    'Blocked': '#FF0000',
    'High': '#D9534F',
    'Bug': '#D9534F',
    'Feature': '#0033CC',
    'Rework': '#F0AD4E',
    'Medium': '#D1D100',
    'Documentation': '#7F8C8D',
    'Review': '#0033CC',
    'To Do': '#F0AD4E',
    'Doing': '#5CB85C',
    'Low': '#44AD8E',
    'Ready': '#00b140',
    'Redacted': '#0000ff',
    'Selected': '#6699cc'
}

BOARDS = {
    'Developement': [ 'Backlog', 'Doing', 'Review', 'Blocked'     ],
    'Priority':     [ 'Low', 'Medium', 'High', 'Critical'         ],
    'Readiness':    [ 'Selected', 'Redacted', 'Ready', 'Backlog'  ],
    'Types':        [ 'Feature', 'Bug', 'Rework', 'Documentation' ]
}
